| Title: | Cases of COVID-19 in France |
|---|---|
| Description: | Imports and cleans 'opencovid19-fr' <https://github.com/opencovid19-fr/data> data on COVID-19 in France. |
| Authors: | Amanda Dobbyn [aut, cre] |
| Maintainer: | Amanda Dobbyn <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0 |
| Built: | 2026-06-05 10:06:24 UTC |
| Source: | https://github.com/cran/covid19france |
Get info about this dataset
get_info_covid19france()get_info_covid19france()
A tibble with information about where the data is pulled from, details about the dataset, what the data types are, etc.
get_info_covid19france()get_info_covid19france()
Refresh data
refresh_covid19france(verbose = TRUE)refresh_covid19france(verbose = TRUE)
verbose |
Should messages about what's going on be displayed? |
A tibble of the most up to date per-day data on cases of COVID-19 in France, ordered by date descending.
refresh_covid19france()refresh_covid19france()